<?php
/*
	Plugin Name: Fixdigital, elementor smartphone
	Description: Additional 'FixDigital Smartphone' element for Elementor.
	Version: 0.2.9
	Author: fixdigital
	License:     GPL2
	License URI: https://www.gnu.org/licenses/gpl-2.0.html
	Text Domain: fix-smartphone-elementor
	Domain Path: /languages/
 */


namespace FixSmartphoneElementor;


use FixSmartphoneElementor\Widgets\FixSmartphone_3_1_0_Plus;
use FixSmartphoneElementor\Widgets\FixSmartphone_Between_3_1_0_And_2_9_0;
use FixSmartphoneElementor\Widgets\FixSmartphone_Before_2_9_0;



if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Plugin {

	public $version;

	protected $assetsUrl;

	public function __construct()
    {
        // set plugin version
        $pluginData     = get_file_data( __FILE__, array( 'Version' => 'Version' ), false );
        $this->version = isset( $pluginData['Version'] ) ? $pluginData['Version'] : '0.0.0';

        $this->assetsUrl = plugins_url( '/assets', __FILE__ );

        add_action( 'plugins_loaded', function(){
            load_plugin_textdomain( 'fix-smartphone-elementor', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
        } );

        add_action( 'elementor/init', [ $this, 'elementorInit' ] );

        add_action( 'wp_enqueue_scripts', [ $this, 'enqueueStyles' ] );
	}


	public function elementorInit()
    {
        if (version_compare( ELEMENTOR_VERSION, '3.5.0', '>=')) {
            add_action('elementor/widgets/register' , [$this, 'registerWidgets']);
        } else {
            add_action('elementor/widgets/widgets_registered' , [$this, 'registerWidgets']);
        }

        $elManager = \Elementor\Plugin::instance()->elements_manager;
        $cats = $elManager->get_categories();

        if (!isset($cats['other-elements'])) {
            // Add element category in panel
            $elManager->add_category(
                'other-elements',
                [
                    'title' => __( 'Other elements' , 'fix-smartphone-elementor' ),
                    'icon' => 'font',
                ],
                1
            );
        }
	}

	/**
	 * @param $manager Elementor\Widgets_Manager
	 *
	 */
	public function registerWidgets( $manager )
    {
        include_once 'widgets/FixSmartphone.php';
        include_once 'widgets/FixSmartphone_3_1_0_Plus.php';
        include_once 'widgets/FixSmartphone_Between_3_1_0_And_2_9_0.php';
        include_once 'widgets/FixSmartphone_Before_2_9_0.php';

        if (version_compare( ELEMENTOR_VERSION, '3.5.0', '>=')) {
            $manager->register( new FixSmartphone_3_1_0_Plus() );
        } else if (version_compare( ELEMENTOR_VERSION, '3.1.0', '>=')) {
            $manager->register_widget_type( new FixSmartphone_3_1_0_Plus() );
        } else if (version_compare( ELEMENTOR_VERSION, '2.9.0', '>=')) {
            $manager->register_widget_type( new FixSmartphone_Between_3_1_0_And_2_9_0() );
        } else {
            $manager->register_widget_type( new FixSmartphone_Before_2_9_0() );
        }
	}


    public function enqueueStyles()
    {
        wp_enqueue_style('fix-smartphone-elementor', $this->assetsUrl . '/css/main.css', null, $this->version );

        // try to connect the font awasome icons because they are absent in last versions of Elementor
        if ( defined('ELEMENTOR_ASSETS_URL') && version_compare( ELEMENTOR_VERSION, '2.5.0', '>=') ) {
            wp_enqueue_style(
                'font-awesome-5',
                ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/fontawesome.min.css',
                [],
                ''
            );

            wp_enqueue_style(
                'solid',
                ELEMENTOR_ASSETS_URL . 'lib/font-awesome/css/solid.min.css',
                [],
                ''
            );
        }
	}

}

new Plugin();


// init plugin update checker
require_once __DIR__ . '/plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = \Puc_v4_Factory::buildUpdateChecker(
    'https://wp-plugins.ln3.tempurl.info/plugin-update-checker/fixdigital-elementor-smartphone.json',
    __FILE__, //Full path to the main plugin file
    'fixdigital-elementor-smartphone'
);